@@ -18,10 +18,10 @@ DEFINE_TEST(test_archive_sha1)
 DEFINE_TEST(test_archive_sha256)
 DEFINE_TEST(test_archive_sha384)
 DEFINE_TEST(test_archive_sha512)
-DEFINE_TEST(test_archive_getdate)
 DEFINE_TEST(test_archive_match_owner)
 DEFINE_TEST(test_archive_match_path)
 DEFINE_TEST(test_archive_match_time)
+DEFINE_TEST(test_archive_parse_date)
 DEFINE_TEST(test_archive_pathmatch)
 DEFINE_TEST(test_archive_read_ahead_eof)
 DEFINE_TEST(test_archive_read_add_passphrase)
@@ -222,10 +222,15 @@ DEFINE_TEST(test_read_format_7zip_ppmd)
 DEFINE_TEST(test_read_format_7zip_lzma2_arm64)
 DEFINE_TEST(test_read_format_7zip_deflate_arm64)
 DEFINE_TEST(test_read_format_7zip_win_attrib)
+DEFINE_TEST(test_read_format_7zip_sfx_pe)
+DEFINE_TEST(test_read_format_7zip_sfx_modified_pe)
+DEFINE_TEST(test_read_format_7zip_sfx_elf)
 DEFINE_TEST(test_read_format_7zip_extract_second)
+DEFINE_TEST(test_read_format_7zip_lzma2_riscv)
 DEFINE_TEST(test_read_format_7zip_lzma2_sparc)
 DEFINE_TEST(test_read_format_7zip_zstd_sparc)
 DEFINE_TEST(test_read_format_7zip_deflate_powerpc)
+DEFINE_TEST(test_read_format_7zip_lzma2_powerpc)
 DEFINE_TEST(test_read_format_7zip_encryption_data)
 DEFINE_TEST(test_read_format_7zip_encryption_header)
 DEFINE_TEST(test_read_format_7zip_encryption_partially)
@@ -278,7 +283,9 @@ DEFINE_TEST(test_read_format_gtar_filename_CP866_CP1251_win)
 DEFINE_TEST(test_read_format_gtar_filename_KOI8R_CP1251)
 DEFINE_TEST(test_read_format_gtar_gz)
 DEFINE_TEST(test_read_format_gtar_lzma)
+DEFINE_TEST(test_read_format_gtar_redundant_L)
 DEFINE_TEST(test_read_format_gtar_sparse)
+DEFINE_TEST(test_read_format_gtar_sparse_length)
 DEFINE_TEST(test_read_format_gtar_sparse_skip_entry)
 DEFINE_TEST(test_read_format_huge_rpm)
 DEFINE_TEST(test_read_format_iso_Z)
@@ -329,8 +336,11 @@ DEFINE_TEST(test_read_format_rar_multivolume_stored_file_skip)
 DEFINE_TEST(test_read_format_rar_multivolume_seek_data)
 DEFINE_TEST(test_read_format_rar_multivolume_seek_multiple_files)
 DEFINE_TEST(test_read_format_rar_multivolume_uncompressed_files)
+DEFINE_TEST(test_read_format_rar_endarc_huge)
 DEFINE_TEST(test_read_format_rar_ppmd_use_after_free)
 DEFINE_TEST(test_read_format_rar_ppmd_use_after_free2)
+DEFINE_TEST(test_read_format_rar_newsub_huge)
+DEFINE_TEST(test_read_format_rar_symlink_huge)
 DEFINE_TEST(test_read_format_rar5_set_format)
 DEFINE_TEST(test_read_format_rar5_stored)
 DEFINE_TEST(test_read_format_rar5_compressed)
@@ -394,6 +404,7 @@ DEFINE_TEST(test_read_format_rar_encryption_header)
 DEFINE_TEST(test_read_format_rar_encryption_partially)
 DEFINE_TEST(test_read_format_rar_filter)
 DEFINE_TEST(test_read_format_rar_invalid1)
+DEFINE_TEST(test_read_format_rar_overflow)
 DEFINE_TEST(test_read_format_raw)
 DEFINE_TEST(test_read_format_tar)
 DEFINE_TEST(test_read_format_tar_concatenated)
@@ -402,6 +413,7 @@ DEFINE_TEST(test_read_format_tar_empty_pax)
 DEFINE_TEST(test_read_format_tar_empty_with_gnulabel)
 DEFINE_TEST(test_read_format_tar_filename)
 DEFINE_TEST(test_read_format_tar_invalid_pax_size)
+DEFINE_TEST(test_read_format_tar_pax_g_large)
 DEFINE_TEST(test_read_format_tar_pax_large_attr)
 DEFINE_TEST(test_read_format_tbz)
 DEFINE_TEST(test_read_format_tgz)
@@ -410,6 +422,7 @@ DEFINE_TEST(test_read_format_txz)
 DEFINE_TEST(test_read_format_tz)
 DEFINE_TEST(test_read_format_ustar_filename)
 DEFINE_TEST(test_read_format_warc)
+DEFINE_TEST(test_read_format_warc_incomplete)
 DEFINE_TEST(test_read_format_xar)
 DEFINE_TEST(test_read_format_xar_duplicate_filename_node)
 DEFINE_TEST(test_read_format_xar_doublelink)
@@ -568,6 +581,7 @@ DEFINE_TEST(test_write_format_7zip_basic_deflate)
 DEFINE_TEST(test_write_format_7zip_basic_lzma1)
 DEFINE_TEST(test_write_format_7zip_basic_lzma2)
 DEFINE_TEST(test_write_format_7zip_basic_ppmd)
+DEFINE_TEST(test_write_format_7zip_basic_zstd)
 DEFINE_TEST(test_write_format_7zip_empty_archive)
 DEFINE_TEST(test_write_format_7zip_empty_files)
 DEFINE_TEST(test_write_format_7zip_large_bzip2)
@@ -576,6 +590,7 @@ DEFINE_TEST(test_write_format_7zip_large_deflate)
 DEFINE_TEST(test_write_format_7zip_large_lzma1)
 DEFINE_TEST(test_write_format_7zip_large_lzma2)
 DEFINE_TEST(test_write_format_7zip_large_ppmd)
+DEFINE_TEST(test_write_format_7zip_large_zstd)
 DEFINE_TEST(test_write_format_ar)
 DEFINE_TEST(test_write_format_cpio)
 DEFINE_TEST(test_write_format_cpio_empty)
@@ -596,6 +611,27 @@ DEFINE_TEST(test_write_format_mtree_classic)
 DEFINE_TEST(test_write_format_mtree_classic_indent)
 DEFINE_TEST(test_write_format_mtree_fflags)
 DEFINE_TEST(test_write_format_mtree_no_separator)
+DEFINE_TEST(test_write_format_mtree_digests_no_digests_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_no_digests_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_no_digests_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_md5_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_md5_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_md5_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_rmd160_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_rmd160_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_rmd160_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha1_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha1_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha1_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha256_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha256_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha256_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha384_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha384_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha384_digest_set_non_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha512_digest_set_no_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha512_digest_set_empty_data)
+DEFINE_TEST(test_write_format_mtree_digests_sha512_digest_set_non_empty_data)
 DEFINE_TEST(test_write_format_mtree_quoted_filename)
 DEFINE_TEST(test_write_format_pax)
 DEFINE_TEST(test_write_format_raw)
@@ -616,7 +652,10 @@ DEFINE_TEST(test_write_format_zip_traditional_pkware_encryption)
 DEFINE_TEST(test_write_format_zip_winzip_aes128_encryption)
 DEFINE_TEST(test_write_format_zip_winzip_aes256_encryption)
 DEFINE_TEST(test_write_format_zip64_stream)
+DEFINE_TEST(test_write_format_zip_compression_bzip2)
+DEFINE_TEST(test_write_format_zip_compression_lzmaxz)
 DEFINE_TEST(test_write_format_zip_compression_store)
+DEFINE_TEST(test_write_format_zip_compression_zstd)
 DEFINE_TEST(test_write_format_zip_empty)
 DEFINE_TEST(test_write_format_zip_empty_zip64)
 DEFINE_TEST(test_write_format_zip_size_unset)
